@@ -38,7 +38,7 @@ public:
 
   static void class_init_function(void* g_class, void* class_data);
 
-  static Glib::ObjectBase* wrap_new(GObject*);
+  static Gst::MiniObject* wrap_new(GstMiniObject*);
 };
 
 
